@@ -1,4 +1,4 @@
-from web.errors.app.application import ApplicationError
+from web.errors.app import ApplicationError
 
 
 class SectionNotFound(ApplicationError):
