@@ -4,6 +4,8 @@ from dataclasses import dataclass, asdict
 from typing import List
 from typing import cast
 
+from pydantic import BaseModel
+
 try:
     import orjson
     from sanic import Sanic
@@ -16,27 +18,23 @@ from web.kernel.types import ConfAble, AppNameAble, ISocket, IService, Transport
 from web.trend.rest.custom import CustomRouter, CustomErrorHandler
 
 
-@dataclass
-class SanicConf:
+class SanicConf(BaseModel):
     access_log: bool | None = False
     noisy_exceptions: bool | None = False
     debug: bool = False
 
 
-@dataclass
-class ServingPaths:
+class ServingPaths(BaseModel):
     uri: str
     path: str
     route: bool = False
 
 
-@dataclass
-class SanicExtConf:
+class SanicExtConf(BaseModel):
     params: SanicConf | None
     serving: dict[str, list[ServingPaths]] | None
 
 
-@dataclass
 class RestTransportConfig(TransportConf):
     sanic: SanicExtConf
 
